@@ -1,5 +1,6 @@
 import mimetypes
 import os
+import pickle
 import shutil
 import socket
 import sys
@@ -184,7 +185,7 @@ class MailTests(MailTestsMixin, SimpleTestCase):
         """Line length check should encode the payload supporting `surrogateescape`.
 
         Following https://github.com/python/cpython/issues/76511, newer
-        versions of Python (3.11.9, 3.12.3 and 3.13) ensure that a message's
+        versions of Python (3.11.9, 3.12.3 and 3.13+) ensure that a message's
         payload is encoded with the provided charset and `surrogateescape` is
         used as the error handling strategy.
 
@@ -652,6 +653,23 @@ class MailTests(MailTestsMixin, SimpleTestCase):
 
         self.assertIn(html_content, msg.message().as_string())
 
+    def test_alternatives_and_attachment_serializable(self):
+        html_content = "<p>This is <strong>html</strong></p>"
+        mime_type = "text/html"
+
+        msg = EmailMultiAlternatives(alternatives=[(html_content, mime_type)])
+        msg.attach("test.txt", "This is plain text.", "plain/text")
+
+        # Alternatives and attachments can be serialized.
+        restored = pickle.loads(pickle.dumps(msg))
+
+        self.assertEqual(restored.subject, msg.subject)
+        self.assertEqual(restored.body, msg.body)
+        self.assertEqual(restored.from_email, msg.from_email)
+        self.assertEqual(restored.to, msg.to)
+        self.assertEqual(restored.alternatives, msg.alternatives)
+        self.assertEqual(restored.attachments, msg.attachments)
+
     def test_none_body(self):
         msg = EmailMessage("subject", None, "from@example.com", ["to@example.com"])
         self.assertEqual(msg.body, "")
